@@ -1,31 +1,15 @@
-"""Umm al-Qura calendar specific constants."""
+"""Umm al-Qura calendar constants."""
 
-"""Range of valid Gregorian dates (inclusive) supported by the converter."""
-gregorian_range = (1924, 8, 1), (2077, 11, 16)
+GREGORIAN_RANGE = (1924, 8, 1), (2077, 11, 16)
+"""Inclusive range of supported Gregorian dates (year, month and day)."""
 
-"""Range of valid Hijri dates (inclusive) supported by the converter."""
-hijri_range = (1343, 1, 1), (1500, 12, 30)
+HIJRI_RANGE = (1343, 1, 1), (1500, 12, 30)
+"""Inclusive range of supported Hijri dates (year, month and day)."""
 
-"""Total Hijri months before the first month."""
-hijri_offset = 1342 * 12
+HIJRI_OFFSET = 1342 * 12
+"""Total Hijri months elapsed before the beginning of Hijri range."""
 
-
-"""Reduced Julian Day (RJD) numbers for the beginning of Hijri months.
-
-Years 1343-1355 AH were calculated by Mohammed Alshehri (dralshehri),
-    based on the issues published by Umm al-Qura newspaper at that time:
-    http://ncar.gov.sa/OmElQuora/List
-Years 1356-1411 AH were calculated by R.H. van Gent, based on
-    the comparison calendar prepared by KFUPM Research Institute:
-    https://www.staff.science.uu.nl/~gent0113/islam/downloads/ksa_calendar_1356_1411.pdf
-Years 1412-1430 AH were calculated by Mohammed Alshehri (dralshehri),
-    based on the issues published by Umm al-Qura newspaper at that time:
-    http://ncar.gov.sa/OmElQuora/List
-Years 1431-1500 AH were calculated by Mohammed Alshehri (dralshehri),
-    based on the tables presented by the website of Umm al-Qura calendar:
-    http://www.ummulqura.org.sa/Index.aspx
-"""
-month_starts = (
+MONTH_STARTS = (
     23999,
     24029,
     24058,
@@ -169,7 +153,7 @@ month_starts = (
     28134,
     28164,
     28193,
-    28224,
+    28223,
     28252,
     28282,
     28311,
@@ -1924,3 +1908,6 @@ month_starts = (
     79960,
     79990,
 )
+"""Ordered list of Reduced Julian Day (RJD) numbers for the beginning of supported
+Hijri months.
+"""
